==> haskell-kan-extensions-5.0.1-12-armv7h.pkg.tar.xz: usr/share/haskell/haskell-kan-extensions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-8b12ed7d1d7d420e05b673cf71306cea
key: kanex_CsVOON1VfTA2iOZ2DxjZw3
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-CsVOON1VfTA2iOZ2DxjZw3
depends:
    adjunctions-4.3-306c4088e5ded361b522da44159f8d3e
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-eb230ef163a26fe6410daceeb92d736a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-1bd57c2540cd2864a467c8bf62a3fdb4
    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
    free-4.12.4-5e68614777ed20792496ad931a527625
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.0.1-13-armv7h.pkg.tar.xz: usr/share/haskell/haskell-kan-extensions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-5603a96458a512e3d069235296b50974
key: kanex_9fdBykvikBU21JxT4cRIKL
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-9fdBykvikBU21JxT4cRIKL
depends:
    adjunctions-4.3-f44cc122c934a46b0d85d56e30c30dce
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-9b3bac8b2740903020c84a0c2eebf7b2
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-1b3716257293d15c38698a7852cba3ac
    distributive-0.5.0.2-77d85d8c453ea57cf04087f9320d2bf7
    free-4.12.4-8e24958a2bab136eded09b725d82baf6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    semigroupoids-5.0.1-8eb2d2c8f0f0def85cbb7c35538a003a
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
